# ##### BEGIN GPL LICENSE BLOCK #####
#
#  This program is free software; you can redistribute it and/or
#  modify it under the terms of the GNU General Public License
#  as published by the Free Software Foundation; either version 2
#  of the License, or (at your option) any later version.
#
#  This program is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#  GNU General Public License for more details.
#
#  You should have received a copy of the GNU General Public License
#  along with this program; if not, write to the Free Software Foundation,
#  Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
#
# ##### END GPL LICENSE BLOCK #####


bl_info = {
    "name": "Расширения для Pie Menu от www.programishka.ru",
    "author": "www.programishka.ru",
    "version": (1, 0, 0),
    "blender": (2, 74, 0),
    'location': 'Двойной клик на клавишу левого CTRL',
    "description": "Расширяет возможности официального Pie menu",
    "category": "User Interface",
    "wiki_url": "http://programishka.ru/index.php?route=product/product&path=59&product_id=153",
    "tracker_url": "http://programishka.ru/index.php?route=information/contact"  
}


import bpy
from bpy.types import Menu, Operator
from bpy.props import EnumProperty
import bpy.ops

# spawn an edit mode selection pie (run while object is in edit mode to get a valid output)
#---------------------------MESH--------------------------------#
class VIEW3D_PIE_func_edit_mode_set(Operator):
    bl_label = "Вызвать функции редактирования объекта"
    bl_idname = "view3d.func_edit_mode"
    
    type = bpy.props.StringProperty()
           
    def execute(self,content):
        if ('pivottoselection' == self.type):
            bpy.ops.view3d.snap_cursor_to_selected()
            bpy.ops.object.mode_set(mode='OBJECT')
            bpy.ops.object.origin_set(type='ORIGIN_CURSOR')
            bpy.ops.object.mode_set(mode='EDIT')
        elif ('clear' == self.type):
            return {'FINISHED'}
        else:
            bpy.ops.wm.call_menu('INVOKE_REGION_WIN', name=""""""+self.type+"""""")
        #print(""""""+self.type+"""""")
        return {'FINISHED'}
    #wm.call_menu

class VIEW3D_PIE_func_edit_mode(Menu):
    # label is displayed at the center of the pie menu.
    bl_label = "Режим редактирования"

    def draw(self, context):
        layout = self.layout

        pie = layout.menu_pie()
        # operator_enum will just spread all available options
        # for the type enum of the operator on the pie
        #pie.operator_enum("mesh.select_mode", "type")
        
        pieitem = pie.operator("view3d.func_edit_mode", icon='SOLO_ON', text='Специальное меню')
        pieitem.type = 'VIEW3D_MT_edit_mesh_specials'
        #print(pieitem.type)
        
        pieitem = pie.operator("view3d.func_edit_mode", icon='SOLO_ON', text="Меню рёбер")
        pieitem.type = 'VIEW3D_MT_edit_mesh_edges'
        
        pieitem = pie.operator("view3d.func_edit_mode", icon='SOLO_ON', text="Меню вершин")
        pieitem.type = 'VIEW3D_MT_edit_mesh_vertices'
        
        pieitem = pie.operator("view3d.func_edit_mode", icon='SOLO_ON', text="Меню граней")
        pieitem.type = 'VIEW3D_MT_edit_mesh_faces'
        
        pieitem = pie.operator("view3d.func_edit_mode", icon='SOLO_ON', text="Меню граней")
        pieitem.type = 'VIEW3D_MT_edit_mesh_faces'
        
        pieitem = pie.operator("view3d.func_edit_mode", icon='SOLO_ON', text="Точку опоры к выделению")
        pieitem.type = 'pivottoselection'
        
        pieitem = pie.operator("mesh.knife_tool", icon='SOLO_ON', text="НОЖ")
        pieitem = pie.operator("mesh.bisect", icon='SOLO_ON', text="Разрезать на 2 части")


#----------------------------------SCULPT---------------------------------#

class VIEW3D_PIE_func_sculpt_mode_set(Operator):
    bl_label = "Вызвать функции скульптинга объекта"
    bl_idname = "view3d.func_sculpt_mode"
    
    type = bpy.props.StringProperty()
           
    def execute(self,content):
        if ('pivottoselection' == self.type):
            return {'FINISHED'}
        elif ('clear' == self.type):
            return {'FINISHED'}
        else:
            bpy.ops.paint.brush_select(paint_mode='SCULPT', sculpt_tool=""""""+self.type+"""""")
        #print(""""""+self.type+"""""")
        return {'FINISHED'}


class VIEW3D_PIE_func_sculpt_mode(Menu):
    
    bl_label = "Режим редактирования"
    
    def draw(self, context):
        layout = self.layout

        pie = layout.menu_pie()
    
        pieitem = pie.operator("view3d.func_sculpt_mode", icon='BRUSH_BLOB', text='Шар')
        pieitem.type = 'BLOB'
        
        pieitem = pie.operator("view3d.func_sculpt_mode", icon='BRUSH_SCULPT_DRAW', text='Кисть')
        pieitem.type = 'DRAW'
        
        pieitem = pie.operator("view3d.func_sculpt_mode", icon='BRUSH_GRAB', text='Тащить')
        pieitem.type = 'GRAB'
        
        pieitem = pie.operator("view3d.func_sculpt_mode", icon='BRUSH_CLAY', text='Глина')
        pieitem.type = 'CLAY'

        pieitem = pie.operator("view3d.func_sculpt_mode", icon='BRUSH_PINCH', text='Заострение')
        pieitem.type = 'PINCH'
        
        pieitem = pie.operator("view3d.func_sculpt_mode", icon='BRUSH_CREASE', text='Складка')
        pieitem.type = 'CREASE'
       
        pieitem = pie.operator("view3d.func_sculpt_mode", icon='BRUSH_SNAKE_HOOK', text='Змея')
        pieitem.type = 'SNAKE_HOOK'
        
        pieitem = pie.operator("view3d.func_sculpt_mode", icon='BRUSH_FLATTEN', text='Порировка')
        pieitem.type = 'FLATTEN'
        

addon_keymaps = []

def register():
    bpy.utils.register_class(VIEW3D_PIE_func_edit_mode_set)
    bpy.utils.register_class(VIEW3D_PIE_func_edit_mode)

    bpy.utils.register_class(VIEW3D_PIE_func_sculpt_mode_set)
    bpy.utils.register_class(VIEW3D_PIE_func_sculpt_mode)

    wm = bpy.context.window_manager
    if wm.keyconfigs.addon:
        
        km = wm.keyconfigs.addon.keymaps.new(name='Mesh')
        kmi = km.keymap_items.new('wm.call_menu_pie', 'LEFT_CTRL', 'DOUBLE_CLICK' , ctrl=True)
        kmi.properties.name = 'VIEW3D_PIE_func_edit_mode'
        addon_keymaps.append(km)
        
        km = wm.keyconfigs.addon.keymaps.new(name='Sculpt')
        kmi = km.keymap_items.new('wm.call_menu_pie', 'LEFT_CTRL', 'DOUBLE_CLICK' , ctrl=True)
        kmi.properties.name = 'VIEW3D_PIE_func_sculpt_mode'

        addon_keymaps.append(km)
        


def unregister():
    
    bpy.utils.unregister_class(VIEW3D_PIE_func_edit_mode_set)
    bpy.utils.unregister_class(VIEW3D_PIE_func_edit_mode)
    
    bpy.utils.unregister_class(VIEW3D_PIE_func_sculpt_mode_set)
    bpy.utils.unregister_class(VIEW3D_PIE_func_sculpt_mode)

    wm = bpy.context.window_manager

    if wm.keyconfigs.addon:
        for km in addon_keymaps:
            for kmi in km.keymap_items:
                km.keymap_items.remove(kmi)

            wm.keyconfigs.addon.keymaps.remove(km)

    # clear the list
    addon_keymaps.clear()


if __name__ == "__main__":
    register()

    #bpy.ops.wm.call_menu_pie(name="VIEW3D_PIE_func_edit_mode")
